@@ -2,8 +2,8 @@
 emacs_is_beta=
 emacs_major_version=21
 emacs_minor_version=4
-emacs_beta_version=0
-xemacs_codename="Solid Vapor"
+emacs_beta_version=3
+xemacs_codename="Academic Rigor"
 infodock_major_version=4
 infodock_minor_version=0
 infodock_build_version=8
